@@ -140,6 +140,8 @@ class Application:
         if self.is_running() and kill_override:
             self.kill_application()
 
+        command_to_use = command if command else self.exec
+
         if in_session:
             pressKey("Esc")
             keyCombo("<Alt><F2>")
@@ -147,12 +149,28 @@ class Application:
             keyCombo("<Alt><F2>")
             sleep(0.5)
             enter_a_command = self.shell.findChild(lambda x: "activate" in x.actions and x.showing)
-            enter_a_command.text = command if command else self.exec
+            enter_a_command.text = command_to_use
             sleep(0.5)
             pressKey("Enter")
         else:
-            self.process = Popen(shlex.split(command if command else self.exec),\
-                 stdout=PIPE, stderr=PIPE)
+            self.process = Popen(shlex.split(command_to_use),
+                                 stdout=PIPE,
+                                 stderr=PIPE,
+                                 encoding="utf-8")
+
+            process_is_running = self.process.poll() is None
+            if not process_is_running:
+                stdout_data, stderr_data = self.process.communicate()
+
+                stdout_data = stdout_data.strip("\n")
+                stderr_data = stderr_data.strip("\n")
+
+                error_message = "\n".join((
+                    f"The command used to start the application '{command_to_use}' failed.",
+                    f"The 'stdout_data' of executed command are: '{stdout_data}'.",
+                    f"The 'stderr_data' of executed command are: '{stderr_data}'."
+                ))
+                raise RuntimeError(error_message)
 
         self.wait_before_app_starts(30)
         self.instance = self.get_root()
