@@ -141,6 +141,8 @@ def start_application(context, application=None, start_via="command", command=No
     elif start_via == "command":
         try:
             application.start_via_command(command=command, in_session=session, kill=kill)
+        except RuntimeError as error:
+            assert False, error
         except Exception:
             application.start_via_command(command=command, in_session=session, kill=kill)
     else:
